ShaderKind

Enum ShaderKind 

#[repr(C)]
pub enum ShaderKind {
Show 30 variants Vertex = 0, Fragment = 1, Compute = 2, Geometry = 3, TessControl = 4, TessEvaluation = 5, InferFromSource = 6, DefaultVertex = 7, DefaultFragment = 8, DefaultCompute = 9, DefaultGeometry = 10, DefaultTessControl = 11, DefaultTessEvaluation = 12, SpirvAssembly = 13, RayGeneration = 14, AnyHit = 15, ClosestHit = 16, Miss = 17, Intersection = 18, Callable = 19, DefaultRayGeneration = 20, DefaultAnyHit = 21, DefaultClosestHit = 22, DefaultMiss = 23, DefaultIntersection = 24, DefaultCallable = 25, Task = 26, Mesh = 27, DefaultTask = 28, DefaultMesh = 29,
}
Shader kind.

  • The <stage> enumerants are forced shader kinds, which force the compiler to compile the source code as the specified kind of shader, regardless of #pragma directives in the source code.
  • The Default<stage> enumerants are default shader kinds, which allow the compiler to fall back to compile the source code as the specified kind of shader when #pragma is not found in the source code.

Variants



Vertex = 0



Fragment = 1



Compute = 2



Geometry = 3



TessControl = 4



TessEvaluation = 5



InferFromSource = 6

Deduce the shader kind from #pragma directives in the source code.

Compiler will emit error if #pragma annotation is not found.



DefaultVertex = 7



DefaultFragment = 8



DefaultCompute = 9



DefaultGeometry = 10



DefaultTessControl = 11



DefaultTessEvaluation = 12



SpirvAssembly = 13



RayGeneration = 14



AnyHit = 15



ClosestHit = 16



Miss = 17



Intersection = 18



Callable = 19



DefaultRayGeneration = 20



DefaultAnyHit = 21



DefaultClosestHit = 22



DefaultMiss = 23



DefaultIntersection = 24



DefaultCallable = 25



Task = 26



Mesh = 27



DefaultTask = 28



DefaultMesh = 29